@@ -2,5 +2,5 @@
 from .schema_qp import SchemaQP
 from .schema_base_config import schema_loglevel
 
-__all__ = ['SchemaQP', 'schema_loglevel', 'datasets']
+__all__ = ['SchemaQP', 'schema_loglevel']
 
